summaryrefslogtreecommitdiffstats
path: root/telecomm/java/android/telecom/Conference.java
diff options
context:
space:
mode:
authorSantos Cordon <santoscordon@google.com>2015-05-12 12:32:51 -0700
committerSantos Cordon <santoscordon@google.com>2015-05-12 12:47:45 -0700
commit5d2e4f20fee033a22fbadffb291c4e47f35b7633 (patch)
tree794908c45ca20b002c125abb0c0a9a2c0d97391b /telecomm/java/android/telecom/Conference.java
parenta2f043822b870f09839d025e146e37f7e7646fc4 (diff)
downloadframeworks_base-5d2e4f20fee033a22fbadffb291c4e47f35b7633.zip
frameworks_base-5d2e4f20fee033a22fbadffb291c4e47f35b7633.tar.gz
frameworks_base-5d2e4f20fee033a22fbadffb291c4e47f35b7633.tar.bz2
Rename Connection time APIs for Conference.java
Bug: 21072487 Change-Id: I7bed9957770639f2adf3c7bd31a4821c0ff0f0dd
Diffstat (limited to 'telecomm/java/android/telecom/Conference.java')
-rw-r--r--telecomm/java/android/telecom/Conference.java41
1 files changed, 32 insertions, 9 deletions
diff --git a/telecomm/java/android/telecom/Conference.java b/telecomm/java/android/telecom/Conference.java
index e682697..89967d6 100644
--- a/telecomm/java/android/telecom/Conference.java
+++ b/telecomm/java/android/telecom/Conference.java
@@ -16,6 +16,7 @@
package android.telecom;
+import android.annotation.SystemApi;
import android.telecom.Connection.VideoProvider;
import java.util.ArrayList;
@@ -116,7 +117,7 @@ public abstract class Conference implements Conferenceable {
}
/**
- * Returns the capabilities of a conference. See {@code CAPABILITY_*} constants in class
+ * Returns the capabilities of the conference. See {@code CAPABILITY_*} constants in class
* {@link Connection} for valid values.
*
* @return A bitmask of the capabilities of the conference call.
@@ -458,8 +459,10 @@ public abstract class Conference implements Conferenceable {
* the connection from which the conference will retrieve its current state.
*
* @return The primary connection.
+ * @hide
*/
- public Connection getPrimaryConnection() {
+ @SystemApi
+ public final Connection getPrimaryConnection() {
if (mUnmodifiableChildConnections == null || mUnmodifiableChildConnections.isEmpty()) {
return null;
}
@@ -467,22 +470,42 @@ public abstract class Conference implements Conferenceable {
}
/**
- * Sets the connect time of the {@code Conference}.
+ * @hide
+ * @deprecated Use {@link #setConnectionTime}.
+ */
+ @Deprecated
+ @SystemApi
+ public final void setConnectTimeMillis(long connectTimeMillis) {
+ setConnectionTime(connectTimeMillis);
+ }
+
+ /**
+ * Sets the connection start time of the {@code Conference}.
*
* @param connectTimeMillis The connection time, in milliseconds.
*/
- public void setConnectTimeMillis(long connectTimeMillis) {
- mConnectTimeMillis = connectTimeMillis;
+ public final void setConnectionTime(long connectionTimeMillis) {
+ mConnectTimeMillis = connectionTimeMillis;
}
/**
- * Retrieves the connect time of the {@code Conference}, if specified. A value of
+ * @hide
+ * @deprecated Use {@link #getConnectionTime}.
+ */
+ @Deprecated
+ @SystemApi
+ public final long getConnectTimeMillis() {
+ return getConnectionTime();
+ }
+
+ /**
+ * Retrieves the connection start time of the {@code Conference}, if specified. A value of
* {@link #CONNECT_TIME_NOT_SPECIFIED} indicates that Telecom should determine the start time
* of the conference.
*
- * @return The time the {@code Conference} has been connected.
+ * @return The time at which the {@code Conference} was connected.
*/
- public final long getConnectTimeMillis() {
+ public final long getConnectionTime() {
return mConnectTimeMillis;
}
@@ -467,22 +470,42 @@ public abstract class Conference implements Conferenceable {
*
- * @param connectTimeMillis The connection time, in milliseconds.
+ * @param connectionTimeMillis The connection time, in milliseconds.
*/